@@ -97,13 +97,14 @@ class Poller(_BaseRepositoryObject):
                                 request = self.repo.request_build(name, series, environment,
                                                                   start, changeset.rev, branch=branch)
                                 logging.info("new build request: {0}".format(request))
+                            self.repo.push()
 
     def test(self):
         """Perform one poll iteration locally as a test.
         """
         for series in self.config.series:
 
-            branches, command, rebuild, _start, sleep = self.config.get_poll(series, all_branches=self.repo.branches)
+            branches, command, rebuild, start, sleep = self.config.get_poll(series, all_branches=self.repo.branches)
             now = time.time()
             if now - self.times[series] > sleep:
 
@@ -124,6 +125,7 @@ class Poller(_BaseRepositoryObject):
                                 else:
                                     request = True
                             if request:
+                                logging.debug("build request would start at [{0}]".format(start))
                                 self.name(self.count, now, series, '<TEST>', changeset, branch)
                                 logging.info("(new) build request: {0}".format(changeset))
 
@@ -159,7 +161,7 @@ def run(config, daemon=False, test=False):
     @param test: run locally as a test
     @return: indicates poller(s) ran successfully
     """
-    pollers = [Poller(repo, config) for repo in config.repos]
+    pollers = [Poller(repo, config.copy()) for repo in config.repos]
     if not pollers:
         return False
 
